==> osb-nrcore-0.5.1.tar.gz: osb-nrcore-0.5.1/kwiq/KWQBrush.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef QBRUSH_H_
#define QBRUSH_H_

#include "KWQColor.h"
#include "KWQNamespace.h"

class QBrush : public Qt {
public: 
    QBrush(const QColor &c = black, BrushStyle style = SolidPattern)
        : brushColor(c), brushStyle(style) { }

    const QColor &color() const { return brushColor; }
    void setColor(const QColor &c) { brushColor = c; }
    BrushStyle style() const { return brushStyle; }
    void setStyle(BrushStyle s) { brushStyle = s; }
    
    bool operator==(const QBrush &b) const { return brushColor == b.brushColor && brushStyle == b.brushStyle; }
    bool operator!=(const QBrush &b) const { return !(*this == b); }

private:
    QColor brushColor;
    BrushStyle brushStyle;
};

#endif

==> osb-nrcore_0.5.1-1.tar.gz: osb-nrcore-0.5.1/kwiq/KWQBrush.h <==
/*
 * Copyright (C) 2003 Apple Computer, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE COMPUTER, INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE COMPUTER, INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */

#ifndef QBRUSH_H_
#define QBRUSH_H_

#include "KWQColor.h"
#include "KWQNamespace.h"

class QBrush : public Qt {
public: 
    QBrush::QBrush(const QColor &c = black, BrushStyle style = SolidPattern)
        : brushColor(c), brushStyle(style) { }

    const QColor &color() const { return brushColor; }
    void setColor(const QColor &c) { brushColor = c; }
    BrushStyle style() const { return brushStyle; }
    void setStyle(BrushStyle s) { brushStyle = s; }
    
    bool operator==(const QBrush &b) const { return brushColor == b.brushColor && brushStyle == b.brushStyle; }
    bool operator!=(const QBrush &b) const { return !(*this == b); }

private:
    QColor brushColor;
    BrushStyle brushStyle;
};

#endif
